import React, { useState } from 'react';
import { motion } from 'framer-motion';
import { Star, Users, Mail, Check, ChevronDown, Sparkles, Heart, Camera } from 'lucide-react';
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import { Checkbox } from "@/components/ui/checkbox";
import { Label } from "@/components/ui/label";
import { toast } from "@/hooks/use-toast";
import { supabase } from "@/integrations/supabase/client";

const CreatorBench = () => {
  const [formData, setFormData] = useState({
    fullName: '',
    email: '',
    instagram: '',
    tiktok: '',
    cityCountry: '',
    mediaKit: '',
    interests: '',
    signature: '',
    agreesToTerms: false,
    understandsNoGuarantee: false,
    confirmsOwnership: false,
    agreesToConfidentiality: false,
    consentsToContact: false,
    wishesToJoin: false
  });

  const [isSubmitted, setIsSubmitted] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  const scrollToForm = () => {
    document.getElementById('agreement-form')?.scrollIntoView({ behavior: 'smooth' });
  };

  const handleInputChange = (field: string, value: string | boolean) => {
    setFormData(prev => ({
      ...prev,
      [field]: value
    }));
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    // Validation
    if (!formData.fullName || !formData.email || !formData.cityCountry || !formData.signature) {
      toast({
        title: "Missing Information",
        description: "Please fill in all required fields.",
        variant: "destructive",
      });
      return;
    }

    if (!formData.understandsNoGuarantee || !formData.confirmsOwnership || 
        !formData.agreesToConfidentiality || !formData.consentsToContact || !formData.wishesToJoin) {
      toast({
        title: "Agreement Required",
        description: "Please check all required agreement boxes to proceed.",
        variant: "destructive",
      });
      return;
    }

    setIsLoading(true);

    try {
      const { data, error } = await supabase
        .from('creator_applications')
        .insert([
          {
            full_name: formData.fullName,
            email: formData.email,
            instagram: formData.instagram,
            tiktok: formData.tiktok,
            city_country: formData.cityCountry,
            media_kit: formData.mediaKit,
            interests: formData.interests,
            signature: formData.signature,
            understands_no_guarantee: formData.understandsNoGuarantee,
            confirms_ownership: formData.confirmsOwnership,
            agrees_to_confidentiality: formData.agreesToConfidentiality,
            consents_to_contact: formData.consentsToContact,
            wishes_to_join: formData.wishesToJoin
          }
        ]);

      if (error) {
        console.error('Supabase error:', error);
        toast({
          title: "Submission Error",
          description: "There was an error submitting your application. Please try again.",
          variant: "destructive",
        });
        return;
      }

      // Send notification email
      try {
        const notificationResponse = await supabase.functions.invoke('send-creator-notification', {
          body: {
            fullName: formData.fullName,
            email: formData.email,
            instagram: formData.instagram,
            tiktok: formData.tiktok,
            cityCountry: formData.cityCountry,
            mediaKit: formData.mediaKit,
            interests: formData.interests,
            signature: formData.signature,
          }
        });

        if (notificationResponse.error) {
          console.error('Notification error:', notificationResponse.error);
        }
      } catch (notificationError) {
        console.error('Failed to send notification:', notificationError);
      }

      setIsSubmitted(true);
      toast({
        title: "Welcome to the Creator Bench! ✨",
        description: "Thank you for joining. We'll reach out when a campaign matches your vibe!",
      });
    } catch (error) {
      console.error('Submission error:', error);
      toast({
        title: "Submission Error",
        description: "Please try again or email us at hello@lunoraaura.com",
        variant: "destructive",
      });
    } finally {
      setIsLoading(false);
    }
  };

  if (isSubmitted) {
    return (
      <div className="min-h-screen bg-gradient-to-br from-[#F7F4EF] to-[#C5B7EA]/20 flex items-center justify-center px-4">
        <motion.div
          initial={{ opacity: 0, scale: 0.8 }}
          animate={{ opacity: 1, scale: 1 }}
          transition={{ duration: 0.6 }}
          className="max-w-2xl text-center"
        >
          <div className="mb-8">
            <Sparkles className="w-20 h-20 text-[#E6B7A9] mx-auto mb-4" />
            <h1 className="text-4xl md:text-5xl font-serif text-[#1C1B2F] mb-4">
              You're In! ✨
            </h1>
            <p className="text-xl text-[#1C1B2F]/70 leading-relaxed mb-8">
              Thank you for joining the Lunora Aura Creator Bench. We'll reach out when a campaign matches your vibe.
            </p>
            <div className="bg-white/60 backdrop-blur-sm rounded-2xl p-6 border border-[#C5B7EA]/20">
              <p className="text-[#1C1B2F]/80 mb-4">
                Questions? Email us at <span className="text-[#E6B7A9] font-medium">hello@lunoraaura.com</span> 💌
              </p>
              <Button 
                onClick={() => window.location.href = '/'}
                className="bg-[#E6B7A9] hover:bg-[#E6B7A9]/90 text-[#1C1B2F] rounded-full px-8 py-3"
              >
                Return to Homepage
              </Button>
            </div>
          </div>
        </motion.div>
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-gradient-to-br from-[#F7F4EF] to-[#C5B7EA]/20">
      {/* Hero Section */}
      <section className="pt-32 pb-20 px-4">
        <div className="max-w-4xl mx-auto text-center">
          <motion.div
            initial={{ opacity: 0, y: 30 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.8 }}
          >
            <div className="flex justify-center items-center mb-6">
              <Sparkles className="w-8 h-8 text-[#E6B7A9] mr-3" />
              <span className="text-[#E6B7A9] font-medium text-lg">Creator Opportunities</span>
              <Sparkles className="w-8 h-8 text-[#E6B7A9] ml-3" />
            </div>
            
            <h1 className="text-5xl md:text-7xl font-serif text-[#1C1B2F] mb-6 leading-tight">
              Join the Lunora Aura
              <span className="block text-[#E6B7A9]">Creator Bench</span>
            </h1>
            
            <p className="text-xl md:text-2xl text-[#1C1B2F]/70 mb-12 max-w-3xl mx-auto leading-relaxed">
              Collaborate with us on upcoming beauty, wellness, and lifestyle campaigns. 
              Submit once, and we'll reach out when there's a perfect match.
            </p>
            
            <Button 
              onClick={scrollToForm}
              className="bg-[#E6B7A9] hover:bg-[#E6B7A9]/90 text-[#1C1B2F] px-12 py-6 text-xl font-medium rounded-full transition-all duration-500 hover:scale-105 hover:shadow-2xl"
            >
              Scroll to Agree & Join
              <ChevronDown className="w-6 h-6 ml-2 animate-bounce" />
            </Button>
          </motion.div>
        </div>
      </section>

      {/* How It Works */}
      <section className="py-20 px-4">
        <div className="max-w-6xl mx-auto">
          <motion.h2 
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
            className="text-4xl md:text-5xl font-serif text-[#1C1B2F] text-center mb-16"
          >
            How It Works
          </motion.h2>
          
          <div className="grid md:grid-cols-3 gap-12">
            {[
              { 
                icon: Check, 
                title: "Read & Agree", 
                desc: "Review the brief terms below",
                number: "01"
              },
              { 
                icon: Users, 
                title: "Submit Your Info", 
                desc: "Fill in your name, handles, and details",
                number: "02"
              },
              { 
                icon: Heart, 
                title: "You're In", 
                desc: "We'll contact you when campaigns align 🎉",
                number: "03"
              }
            ].map((step, index) => (
              <motion.div
                key={index}
                initial={{ opacity: 0, y: 30 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.2 }}
                viewport={{ once: true }}
                className="text-center"
              >
                <div className="relative mb-8">
                  <div className="w-20 h-20 mx-auto bg-gradient-to-br from-[#C5B7EA] to-[#E6B7A9] rounded-2xl flex items-center justify-center shadow-lg">
                    <step.icon className="w-10 h-10 text-white" />
                  </div>
                  <div className="absolute -top-2 -right-2 w-8 h-8 bg-[#1C1B2F] text-white rounded-full flex items-center justify-center text-sm font-bold">
                    {step.number}
                  </div>
                </div>
                <h3 className="text-2xl font-semibold text-[#1C1B2F] mb-4 font-serif">{step.title}</h3>
                <p className="text-[#1C1B2F]/70 text-lg">{step.desc}</p>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* MOU Summary */}
      <section className="py-20 px-4 bg-white/50">
        <div className="max-w-4xl mx-auto">
          <motion.div
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-4xl md:text-5xl font-serif text-[#1C1B2F] text-center mb-4">
              📝 What You're Agreeing To
            </h2>
            <p className="text-xl text-[#1C1B2F]/70 text-center mb-12 leading-relaxed">
              You're joining our internal roster of trusted influencers (our Creator Bench). This doesn't promise paid work, 
              but it gives us permission to reach out when brand projects come up. You're always free to say yes or no to any opportunity.
            </p>
            
            <div className="grid md:grid-cols-2 gap-8">
              <Card className="bg-white/80 border-[#C5B7EA]/20 shadow-lg">
                <CardHeader>
                  <CardTitle className="text-2xl font-serif text-[#1C1B2F] flex items-center">
                    <Star className="w-6 h-6 text-[#E6B7A9] mr-3" />
                    What We Ask of You
                  </CardTitle>
                </CardHeader>
                <CardContent className="space-y-4">
                  {[
                    "Your info stays private and safe",
                    "You'll only be contacted with relevant campaigns",
                    "You confirm your social media accounts belong to you",
                    "You won't share campaign details unless authorized"
                  ].map((item, index) => (
                    <div key={index} className="flex items-start">
                      <Check className="w-5 h-5 text-[#E6B7A9] mr-3 mt-1 flex-shrink-0" />
                      <span className="text-[#1C1B2F]/80">{item}</span>
                    </div>
                  ))}
                </CardContent>
              </Card>
              
              <Card className="bg-white/80 border-[#C5B7EA]/20 shadow-lg">
                <CardHeader>
                  <CardTitle className="text-2xl font-serif text-[#1C1B2F] flex items-center">
                    <Heart className="w-6 h-6 text-[#E6B7A9] mr-3" />
                    What You Get
                  </CardTitle>
                </CardHeader>
                <CardContent className="space-y-4">
                  {[
                    "Early access to select campaigns",
                    "Freedom to choose when and how you collaborate",
                    "A seat at the table for future brand opportunities"
                  ].map((item, index) => (
                    <div key={index} className="flex items-start">
                      <Star className="w-5 h-5 text-[#E6B7A9] mr-3 mt-1 flex-shrink-0" />
                      <span className="text-[#1C1B2F]/80">{item}</span>
                    </div>
                  ))}
                </CardContent>
              </Card>
            </div>
          </motion.div>
        </div>
      </section>

      {/* Agreement Form */}
      <section id="agreement-form" className="py-20 px-4">
        <div className="max-w-4xl mx-auto">
          <motion.div
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-4xl md:text-5xl font-serif text-[#1C1B2F] text-center mb-12">
              Join Our Creator Bench
            </h2>
            
            <Card className="bg-white/80 border-[#C5B7EA]/20 shadow-2xl backdrop-blur-sm">
              <CardContent className="p-8">
                <form onSubmit={handleSubmit} className="space-y-8">
                  {/* Basic Information */}
                  <div className="space-y-6">
                    <h3 className="text-2xl font-semibold text-[#1C1B2F] border-b border-[#C5B7EA]/20 pb-3">
                      Your Information
                    </h3>
                    
                    <div className="grid md:grid-cols-2 gap-6">
                      <div>
                        <Label htmlFor="fullName" className="text-[#1C1B2F] font-medium mb-2 block">
                          Full Legal Name *
                        </Label>
                        <Input
                          id="fullName"
                          value={formData.fullName}
                          onChange={(e) => handleInputChange('fullName', e.target.value)}
                          className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl"
                          required
                        />
                      </div>
                      
                      <div>
                        <Label htmlFor="email" className="text-[#1C1B2F] font-medium mb-2 block">
                          Email Address *
                        </Label>
                        <Input
                          id="email"
                          type="email"
                          value={formData.email}
                          onChange={(e) => handleInputChange('email', e.target.value)}
                          className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl"
                          required
                        />
                      </div>
                    </div>
                    
                    <div className="grid md:grid-cols-2 gap-6">
                      <div>
                        <Label htmlFor="instagram" className="text-[#1C1B2F] font-medium mb-2 block">
                          Instagram Handle
                        </Label>
                        <Input
                          id="instagram"
                          value={formData.instagram}
                          onChange={(e) => handleInputChange('instagram', e.target.value)}
                          placeholder="@yourusername"
                          className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl"
                        />
                      </div>
                      
                      <div>
                        <Label htmlFor="tiktok" className="text-[#1C1B2F] font-medium mb-2 block">
                          TikTok Handle
                        </Label>
                        <Input
                          id="tiktok"
                          value={formData.tiktok}
                          onChange={(e) => handleInputChange('tiktok', e.target.value)}
                          placeholder="@yourusername"
                          className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl"
                        />
                      </div>
                    </div>
                    
                    <div>
                      <Label htmlFor="cityCountry" className="text-[#1C1B2F] font-medium mb-2 block">
                        City & Country *
                      </Label>
                      <Input
                        id="cityCountry"
                        value={formData.cityCountry}
                        onChange={(e) => handleInputChange('cityCountry', e.target.value)}
                        placeholder="Toronto, Canada"
                        className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl"
                        required
                      />
                    </div>
                    
                    <div>
                      <Label htmlFor="mediaKit" className="text-[#1C1B2F] font-medium mb-2 block">
                        Link to Media Kit
                      </Label>
                      <Input
                        id="mediaKit"
                        value={formData.mediaKit}
                        onChange={(e) => handleInputChange('mediaKit', e.target.value)}
                        placeholder="https://..."
                        className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl"
                      />
                    </div>
                    
                    <div>
                      <Label htmlFor="interests" className="text-[#1C1B2F] font-medium mb-2 block">
                        Interests/Niches
                      </Label>
                      <Textarea
                        id="interests"
                        value={formData.interests}
                        onChange={(e) => handleInputChange('interests', e.target.value)}
                        placeholder="Tell us about your content style, interests, and what makes you unique..."
                        rows={4}
                        className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl resize-none"
                      />
                    </div>
                  </div>

                  {/* Agreement Checkboxes */}
                  <div className="space-y-6">
                    <h3 className="text-2xl font-semibold text-[#1C1B2F] border-b border-[#C5B7EA]/20 pb-3">
                      Agreement
                    </h3>
                    
                    <div className="space-y-4">
                      {[
                        { key: 'understandsNoGuarantee', text: 'I understand this is not a paid opportunity guarantee.' },
                        { key: 'confirmsOwnership', text: 'I confirm I own and manage the accounts I submit.' },
                        { key: 'agreesToConfidentiality', text: 'I agree to keep brand information confidential.' },
                        { key: 'consentsToContact', text: 'I consent to being contacted by Lunora Aura about future campaigns.' }
                      ].map((item) => (
                        <div key={item.key} className="flex items-start space-x-3 p-4 bg-[#F7F4EF]/50 rounded-xl">
                          <Checkbox
                            id={item.key}
                            checked={formData[item.key as keyof typeof formData] as boolean}
                            onCheckedChange={(checked) => handleInputChange(item.key, checked as boolean)}
                            className="mt-1"
                          />
                          <Label htmlFor={item.key} className="text-[#1C1B2F]/80 leading-relaxed">
                            {item.text}
                          </Label>
                        </div>
                      ))}
                    </div>
                    
                    <div className="bg-[#C5B7EA]/10 p-6 rounded-xl">
                      <h4 className="text-lg font-semibold text-[#1C1B2F] mb-4">
                        Do you agree to these terms and wish to join our Creator Bench?
                      </h4>
                      <div className="flex items-center space-x-3">
                        <Checkbox
                          id="wishesToJoin"
                          checked={formData.wishesToJoin}
                          onCheckedChange={(checked) => handleInputChange('wishesToJoin', checked as boolean)}
                        />
                        <Label htmlFor="wishesToJoin" className="text-[#1C1B2F] font-medium">
                          ✅ Yes, I agree and wish to join
                        </Label>
                      </div>
                    </div>
                  </div>

                  {/* Digital Signature */}
                  <div className="space-y-6">
                    <h3 className="text-2xl font-semibold text-[#1C1B2F] border-b border-[#C5B7EA]/20 pb-3">
                      Digital Signature
                    </h3>
                    
                    <div>
                      <Label htmlFor="signature" className="text-[#1C1B2F] font-medium mb-2 block">
                        Type your full name as your digital signature *
                      </Label>
                      <Input
                        id="signature"
                        value={formData.signature}
                        onChange={(e) => handleInputChange('signature', e.target.value)}
                        placeholder="Your Full Name"
                        className="border-[#C5B7EA]/30 focus:border-[#E6B7A9] rounded-xl font-serif text-lg"
                        required
                      />
                      <p className="text-sm text-[#1C1B2F]/60 mt-2">
                        By typing your name above, you acknowledge this as your digital signature.
                      </p>
                    </div>
                    
                    <div className="text-center">
                      <p className="text-[#1C1B2F]/60 mb-2">Today's Date</p>
                      <p className="text-[#1C1B2F] font-medium">{new Date().toLocaleDateString()}</p>
                    </div>
                  </div>

                  {/* Submit Button */}
                  <div className="pt-6">
                    <Button
                      type="submit"
                      disabled={isLoading}
                      className="w-full bg-[#E6B7A9] hover:bg-[#E6B7A9]/90 text-[#1C1B2F] py-6 text-xl font-semibold rounded-xl transition-all duration-500 hover:scale-105"
                    >
                      {isLoading ? (
                        <div className="flex items-center">
                          <div className="w-6 h-6 border-2 border-[#1C1B2F]/30 border-t-[#1C1B2F] rounded-full animate-spin mr-3"></div>
                          Submitting...
                        </div>
                      ) : (
                        <>
                          <Sparkles className="w-6 h-6 mr-3" />
                          Join the Creator Bench
                        </>
                      )}
                    </Button>
                  </div>
                </form>
              </CardContent>
            </Card>
          </motion.div>
        </div>
      </section>
    </div>
  );
};

export default CreatorBench;
